==> 2.2.3.tar.gz: lib/src/core/data.service.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:api_cache_manager/models/cache_db_model.dart';
import 'package:api_cache_manager/utils/cache_manager.dart';
import 'package:dio/dio.dart';
import 'package:global_configuration/global_configuration.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:http/http.dart' as http;
import 'dart:developer';
import 'auth.service.dart';

class DataService {
  static bool isButtonDisabled = false;

  static Future<Map> getHeaders() async {
    final bool isLoggedIn = await AuthService.isLoggedIn();
    final accessToken = await AuthService.getAccessToken();

    var data = {
      HttpHeaders.contentTypeHeader: 'application/json',
      if (isLoggedIn && accessToken != null)
        HttpHeaders.authorizationHeader: 'Bearer $accessToken',
    };
    return data;
  }

  static Future<Map> get(String url,
      {Map<String, String> params, bool enableCache = false}) async {
    //Method to check actual internet connection
    Future<bool> checkIsInternetConnected() async {
      try {
        final result = await InternetAddress.lookup('google.com');
        if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
          return true;
        }
      } on SocketException catch (_) {
        return false;
      }
      return false;
    }

    bool isConnected = await checkIsInternetConnected();

    Future<Map> getResponse() async {
      http.Response response = await http.get(
        Uri.https(
          GlobalConfiguration().getValue<String>('coreDomain'),
          GlobalConfiguration().getValue<String>('baseUri') + url,
          params,
        ),
        headers: await DataService.getHeaders(),
      );
      if (response.statusCode != 200 && response.statusCode != 201) {
        print(response.body);
        if (json.decode(response.body) is Map &&
            json.decode(response.body).containsKey('error'))
          Fluttertoast.showToast(msg: json.decode(response.body)['error']);
        else
          Fluttertoast.showToast(
            msg: 'Failed to fetch data',
            toastLength: Toast.LENGTH_SHORT,
            gravity: ToastGravity.BOTTOM,
          );
        return {'item': [], 'data': []};
      } else {
        if (enableCache) {
          APICacheDBModel cacheDBModel =
              APICacheDBModel(key: url, syncData: response.body);
          await APICacheManager().addCacheData(cacheDBModel);
        }

        return response.body.isNotEmpty
            ? (json.decode(response.body) is List)
                ? {'data': json.decode(response.body)}
                : json.decode(response.body)
            : {"item": []};
      }
    }

    if (enableCache && !isConnected) {
      var data = await getCache(url);
      if (data != null)
        return data;
      else
        return getResponse();
    } else
      return getResponse();
  }

  static Future<Map> getCache(
    String key,
  ) async {
    var isCacheExists = await APICacheManager().isAPICacheKeyExist(key);
    if (!isCacheExists) {
      return null;
    } else {
      var cacheData = await APICacheManager().getCacheData(key);

      return cacheData.syncData.isNotEmpty
          ? (json.decode(cacheData.syncData) is List)
              ? {'data': json.decode(cacheData.syncData)}
              : json.decode(cacheData.syncData)
          : null;
    }
  }

  static Future<void> emptyCache() async {
    await APICacheManager().emptyCache();
  }

  static Future<Map> post(String url, Map data, [bool showToast = true]) async {
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.post(
      fullUrl,
      body: json.encode(data),
      headers: await DataService.getHeaders(),
    );
    print(response.body);
    if (response.statusCode != 200 && response.statusCode != 201) {
      if (showToast)
        Fluttertoast.showToast(
          msg: response.body.isNotEmpty
              ? jsonDecode(response.body)['error'] ?? 'Failed to create Data'
              : "Failed to create a data",
          toastLength: Toast.LENGTH_SHORT,
          gravity: ToastGravity.BOTTOM,
        );
      return null;
    }
    return json.decode(response.body);
  }

  static Future<Map> postRaw(String url, data) async {
    isButtonDisabled = true;
    Response response = await Dio().post(
      "http://" +
          GlobalConfiguration().getValue<String>('coreDomain') +
          GlobalConfiguration().getValue<String>('baseUri') +
          url,
      data: data,
      options: Options(
        headers: {
          HttpHeaders.authorizationHeader:
              'Bearer ' + await AuthService.getAccessToken(),
        },
      ),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200) {
      Fluttertoast.showToast(
        msg: "Failed to create a data",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }
    var dataList = response.data.values.toList();
    return dataList[0];
  }

  static Future<Map> put(String url, Map data) async {
    isButtonDisabled = true;
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.put(
      fullUrl,
      body: json.encode(data),
      headers: await DataService.getHeaders(),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200 && response.statusCode != 201) {
      log(response.body);
      print(response.statusCode);
      Fluttertoast.showToast(
        msg: "Failed to update",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }

    return json.decode(response.body);
  }

  static Future<Map> delete(String url) async {
    isButtonDisabled = true;
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.delete(
      fullUrl,
      headers: await DataService.getHeaders(),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200) {
      print(response.body);
      print(response.statusCode);
      Fluttertoast.showToast(
        msg: "Failed to delete",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }
    return json.decode(response.body);
  }

  static Future<Map> patch(String url, Map data) async {
    isButtonDisabled = true;
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.patch(
      fullUrl,
      body: json.encode(data),
      headers: await DataService.getHeaders(),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200) {
      Fluttertoast.showToast(
        msg: "Failed to update",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }

    return json.decode(response.body);
  }
}

==> 2.2.4.tar.gz: lib/src/core/data.service.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:api_cache_manager/models/cache_db_model.dart';
import 'package:api_cache_manager/utils/cache_manager.dart';
import 'package:dio/dio.dart';
import 'package:global_configuration/global_configuration.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:http/http.dart' as http;
import 'dart:developer';
import 'auth.service.dart';

class DataService {
  static bool isButtonDisabled = false;

  static Future<Map> getHeaders() async {
    final accessToken = await AuthService.getAccessToken();

    var data = {
      HttpHeaders.contentTypeHeader: 'application/json',
      if (accessToken != null)
        HttpHeaders.authorizationHeader: 'Bearer $accessToken',
    };
    return data;
  }

  static Future<Map> get(String url,
      {Map<String, String> params, bool enableCache = false}) async {
    //Method to check actual internet connection
    Future<bool> checkIsInternetConnected() async {
      try {
        final result = await InternetAddress.lookup('google.com');
        if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
          return true;
        }
      } on SocketException catch (_) {
        return false;
      }
      return false;
    }

    bool isConnected = await checkIsInternetConnected();

    Future<Map> getResponse() async {
      http.Response response = await http.get(
        Uri.https(
          GlobalConfiguration().getValue<String>('coreDomain'),
          GlobalConfiguration().getValue<String>('baseUri') + url,
          params,
        ),
        headers: await DataService.getHeaders(),
      );
      if (response.statusCode != 200 && response.statusCode != 201) {
        print(response.body);
        if (json.decode(response.body) is Map &&
            json.decode(response.body).containsKey('error'))
          Fluttertoast.showToast(
              msg: json.decode(response.body)['error'].toString());
        else
          Fluttertoast.showToast(
            msg: 'Failed to fetch data',
            toastLength: Toast.LENGTH_SHORT,
            gravity: ToastGravity.BOTTOM,
          );
        return null;
      } else {
        if (enableCache) {
          APICacheDBModel cacheDBModel =
              APICacheDBModel(key: url, syncData: response.body);
          await APICacheManager().addCacheData(cacheDBModel);
        }

        return response.body.isNotEmpty
            ? (json.decode(response.body) is List)
                ? {'data': json.decode(response.body)}
                : json.decode(response.body)
            : {"item": []};
      }
    }

    if (enableCache && !isConnected) {
      var data = await getCache(url);
      if (data != null)
        return data;
      else
        return getResponse();
    } else
      return getResponse();
  }

  static Future<Map> getCache(
    String key,
  ) async {
    var isCacheExists = await APICacheManager().isAPICacheKeyExist(key);
    if (!isCacheExists) {
      return null;
    } else {
      var cacheData = await APICacheManager().getCacheData(key);

      return cacheData.syncData.isNotEmpty
          ? (json.decode(cacheData.syncData) is List)
              ? {'data': json.decode(cacheData.syncData)}
              : json.decode(cacheData.syncData)
          : null;
    }
  }

  static Future<void> emptyCache() async {
    await APICacheManager().emptyCache();
  }

  static Future<Map> post(String url, Map data, [bool showToast = true]) async {
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.post(
      fullUrl,
      body: json.encode(data),
      headers: await DataService.getHeaders(),
    );
    log(response.body);
    if (response.statusCode != 200 && response.statusCode != 201) {
      if (showToast)
        Fluttertoast.showToast(
          msg: response.body.isNotEmpty
              ? jsonDecode(response.body)['error'] ?? 'Failed to create Data'
              : "Failed to create a data",
          toastLength: Toast.LENGTH_SHORT,
          gravity: ToastGravity.BOTTOM,
        );
      return null;
    }
    return json.decode(response.body);
  }

  static Future<Map> postRaw(String url, data) async {
    isButtonDisabled = true;
    Response response = await Dio().post(
      "http://" +
          GlobalConfiguration().getValue<String>('coreDomain') +
          GlobalConfiguration().getValue<String>('baseUri') +
          url,
      data: data,
      options: Options(
        headers: {
          HttpHeaders.authorizationHeader:
              'Bearer ' + await AuthService.getAccessToken(),
        },
      ),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200) {
      Fluttertoast.showToast(
        msg: "Failed to create a data",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }
    var dataList = response.data.values.toList();
    return dataList[0];
  }

  static Future<Map> put(String url, Map data) async {
    isButtonDisabled = true;
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.put(
      fullUrl,
      body: json.encode(data),
      headers: await DataService.getHeaders(),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200 && response.statusCode != 201) {
      log(response.body);
      print(response.statusCode);
      Fluttertoast.showToast(
        msg: "Failed to update",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }

    return json.decode(response.body);
  }

  static Future<Map> delete(String url) async {
    isButtonDisabled = true;
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.delete(
      fullUrl,
      headers: await DataService.getHeaders(),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200) {
      print(response.body);
      print(response.statusCode);
      Fluttertoast.showToast(
        msg: "Failed to delete",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }
    return json.decode(response.body);
  }

  static Future<Map> patch(String url, Map data) async {
    isButtonDisabled = true;
    var fullUrl = Uri.https(
      GlobalConfiguration().getValue<String>('coreDomain'),
      GlobalConfiguration().getValue<String>('baseUri') + url,
    );
    http.Response response = await http.patch(
      fullUrl,
      body: json.encode(data),
      headers: await DataService.getHeaders(),
    );
    isButtonDisabled = false;
    if (response.statusCode != 200) {
      Fluttertoast.showToast(
        msg: response.body.isNotEmpty
            ? jsonDecode(response.body)['error'] ?? 'Failed to update'
            : "Failed to update",
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.BOTTOM,
      );
      return null;
    }

    return json.decode(response.body);
  }
}
